@@ -73,7 +73,7 @@ class Exceptions:
 
 class CodeGuruReviewerClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguru_reviewer/client.html)
     """
 
@@ -83,19 +83,23 @@ class CodeGuruReviewerClient:
     def associate_repository(
         self,
         *,
-        Repository: RepositoryTypeDef,
+        Repository: "RepositoryTypeDef",
         ClientRequestToken: str = None,
         Tags: Dict[str, str] = None,
         KMSKeyDetails: "KMSKeyDetailsTypeDef" = None
     ) -> AssociateRepositoryResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.associate_repository)
+        .
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.associate_repository)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguru_reviewer/client.html#associate_repository)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.can_paginate)
+        Check if an operation can be paginated.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguru_reviewer/client.html#can_paginate)
         """
 
@@ -104,17 +108,21 @@ class CodeGuruReviewerClient:
         *,
         Name: str,
         RepositoryAssociationArn: str,
-        Type: CodeReviewTypeTypeDef,
+        Type: "CodeReviewTypeTypeDef",
         ClientRequestToken: str = None
     ) -> CreateCodeReviewResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.create_code_review)
+        .
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.create_code_review)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguru_reviewer/client.html#create_code_review)
         """
 
     def describe_code_review(self, *, CodeReviewArn: str) -> DescribeCodeReviewResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.describe_code_review)
+        .
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.describe_code_review)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguru_reviewer/client.html#describe_code_review)
         """
 
@@ -122,7 +130,9 @@ class CodeGuruReviewerClient:
         self, *, CodeReviewArn: str, RecommendationId: str, UserId: str = None
     ) -> DescribeRecommendationFeedbackResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.describe_recommendation_feedback)
+        .
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.describe_recommendation_feedback)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguru_reviewer/client.html#describe_recommendation_feedback)
         """
 
@@ -130,7 +140,9 @@ class CodeGuruReviewerClient:
         self, *, AssociationArn: str
     ) -> DescribeRepositoryAssociationResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.describe_repository_association)
+        .
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.describe_repository_association)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguru_reviewer/client.html#describe_repository_association)
         """
 
@@ -138,7 +150,9 @@ class CodeGuruReviewerClient:
         self, *, AssociationArn: str
     ) -> DisassociateRepositoryResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.disassociate_repository)
+        .
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.disassociate_repository)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguru_reviewer/client.html#disassociate_repository)
         """
 
@@ -150,7 +164,9 @@ class CodeGuruReviewerClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.generate_presigned_url)
+        Generate a presigned url given a client, its method, and arguments.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguru_reviewer/client.html#generate_presigned_url)
         """
 
@@ -165,7 +181,9 @@ class CodeGuruReviewerClient:
         NextToken: str = None
     ) -> ListCodeReviewsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.list_code_reviews)
+        .
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.list_code_reviews)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguru_reviewer/client.html#list_code_reviews)
         """
 
@@ -179,7 +197,9 @@ class CodeGuruReviewerClient:
         RecommendationIds: List[str] = None
     ) -> ListRecommendationFeedbackResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.list_recommendation_feedback)
+        .
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.list_recommendation_feedback)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguru_reviewer/client.html#list_recommendation_feedback)
         """
 
@@ -187,7 +207,9 @@ class CodeGuruReviewerClient:
         self, *, CodeReviewArn: str, NextToken: str = None, MaxResults: int = None
     ) -> ListRecommendationsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.list_recommendations)
+        .
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.list_recommendations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguru_reviewer/client.html#list_recommendations)
         """
 
@@ -202,13 +224,17 @@ class CodeGuruReviewerClient:
         NextToken: str = None
     ) -> ListRepositoryAssociationsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.list_repository_associations)
+        .
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.list_repository_associations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguru_reviewer/client.html#list_repository_associations)
         """
 
     def list_tags_for_resource(self, *, resourceArn: str) -> ListTagsForResourceResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.list_tags_for_resource)
+        .
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguru_reviewer/client.html#list_tags_for_resource)
         """
 
@@ -216,19 +242,25 @@ class CodeGuruReviewerClient:
         self, *, CodeReviewArn: str, RecommendationId: str, Reactions: List[ReactionType]
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.put_recommendation_feedback)
+        .
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.put_recommendation_feedback)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguru_reviewer/client.html#put_recommendation_feedback)
         """
 
     def tag_resource(self, *, resourceArn: str, Tags: Dict[str, str]) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.tag_resource)
+        .
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguru_reviewer/client.html#tag_resource)
         """
 
     def untag_resource(self, *, resourceArn: str, TagKeys: List[str]) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.untag_resource)
+        .
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguru_reviewer/client.html#untag_resource)
         """
 
@@ -236,7 +268,8 @@ class CodeGuruReviewerClient:
         self, operation_name: Literal["list_repository_associations"]
     ) -> ListRepositoryAssociationsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Paginator.ListRepositoryAssociations)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguru_reviewer/paginators.html#listrepositoryassociationspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Paginator.ListRepositoryAssociations)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguru_reviewer/paginators.html#listrepositoryassociationspaginator)
         """
 
     @overload
@@ -244,7 +277,8 @@ class CodeGuruReviewerClient:
         self, waiter_name: Literal["code_review_completed"]
     ) -> CodeReviewCompletedWaiter:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Waiter.code_review_completed)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguru_reviewer/waiters.html#codereviewcompletedwaiter)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Waiter.CodeReviewCompleted)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguru_reviewer/waiters.html#codereviewcompletedwaiter)
         """
 
     @overload
@@ -252,5 +286,6 @@ class CodeGuruReviewerClient:
         self, waiter_name: Literal["repository_association_succeeded"]
     ) -> RepositoryAssociationSucceededWaiter:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Waiter.repository_association_succeeded)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguru_reviewer/waiters.html#repositoryassociationsucceededwaiter)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Waiter.RepositoryAssociationSucceeded)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguru_reviewer/waiters.html#repositoryassociationsucceededwaiter)
         """
